# uniapp-project

## Project setup
```
npm install
```

### Compiles and hot-reloads for development
```
npm run dev
```

### Compiles and minifies for production
```
npm run build
```

### eslint fix

```
npm run lint
```

### config husky

```
npm run prepare
```

## 目录结构

```
--public
  --index.html  // html模板
--src
  --components // 全局组件
  --pages // 页面
  --plugins // 插件，axios等
  --static // 静态资源
  --store // 状态管理
  --utils // 工具
  App.vue // 根组件
  config.js // 配置文件，根据环境导出不同的全局配置，hostPrefix、apiPrefix 等
  main.js // 入口文件
  pages.json // 小程序页面配置
```

### 组件库

项目接入了 `uView` 组件库，可以直接在 `template` 中使用组件，无需引入

## 请求

接入了 axios ，并进行了简单封装，通过 `this.$request` 发起请求。

请求拦截中会在 header 中带上 uid，accessToken。

响应拦截中有未登录处理，错误处理等。

```javascript
// Promise 写法
this.$request.get('xxx').then(res => {})

// async/await 写法
const res = await this.$request.post('xxx')

// 传参
const params = {}
this.$request.get('xxx', {
  params
})
this.$request.post('xxx', params)
```

## 登录

提供了 `phone-login` 组件，用来调用手机号授权登录

登录接口需要在 store/modules/user.js 文件下的 login 方法中实现

## 埋点

目前前端的埋点库还不支持小程序，所以在 `utils/util.js` 里面封装了一个埋点请求，`sendTrackData`.

埋点封装的函数中的 `app_name` 参数需要根据实际项目定义填写进去。

埋点示例如下：

```javascript
setTrackData({
  events: [
    {
      event_id: 'page_visit',
      event_custom_properties: {
        part: 'xxx',
        position: '',
        element: '',
      },
    },
  ],
})
```

## 代码风格

vscode 安装 ESLlint、Vetur、Prettier 这三个插件。

### Eslint

统一代码风格

### Vetur

让 vscode 识别 .vue 文件，实现语法高亮

### Prettier

格式化代码

vscode 设置里面勾选 Format On Save 可以在保存的时候格式化代码

## 提交规范

### 使用 commitizen 规范 commit 信息

全局安装 commitizen

```
npm install -g commitizen
```

安装后就可以使用 `git cz` 命令来提交代码了，cz 在命令行里面提供选项可以选择。

### 使用 husky 添加 git hook

npm install 时会自动执行 prepare 命令，执行该命令需要在项目根目录下有 .git 目录。如果没有执行该命令，手动执行下：

```
npm run prepare
```

增加 pre-commit hook:

```
// npm run lint 就是 commit 时要执行的命令，可根据实际命令调整
npx husky add .husky/pre-commit "npm run lint"
git add .husky/pre-commit
```
