/* eslint-disable no-undef */
import adapter from 'axios-adapter-uniapp'
import axios from 'axios'
import store from '@/store'
import { apiPrefix } from '@/config'

axios.defaults.headers['Content-Type'] = 'application/json;charset=utf-8'

const baseURL = `${apiPrefix}/api`
const timeout = 20000

const service = axios.create({
  baseURL,
  timeout,
  adapter,
})

// 请求拦截
service.interceptors.request.use(request => {
  const accessToken = store.state.user.accessToken
  if (accessToken) request.headers.accessToken = accessToken
  const uid = store.state.user.uid
  if (uid) request.headers.uid = uid
  return request
})

// 响应拦截
service.interceptors.response.use(async res => {
  // 配置了clearCode，清空store里面的code，获取最新的
  if (res.config && res.config.clearCode) {
    store.commit('user/setCode', '')
    store.dispatch('user/uniLogin')
  }
  if (res.status === 200 && res.data) {
    const code = +res.data.code
    if (code === 200) {
      return Promise.resolve(res.data.data)
    } else if (code === 401) {
      clearUserInfo()
      uni.showToast({
        title: '请先登录',
        icon: 'none',
      })
      return Promise.reject(new Error('unlogin'))
    } else if (
      code === 40029 ||
      code === 40163 ||
      (res.data.errMsg || res.data.msg).includes('40029') ||
      (res.data.errMsg || res.data.msg).includes('40163')
    ) {
      clearUserInfo()
      uni.showToast({
        title: 'code已过期，请重新登录',
        icon: 'none',
      })
      store.dispatch('user/uniLogin')
      return Promise.reject(new Error('unlogin'))
    } else {
      if (res.data.errMsg || res.data.msg) {
        // 错误统一处理
        uni.showToast({
          title: res.data.errMsg || res.data.msg,
          icon: 'none',
        })
      }
      return Promise.reject(res.data.errMsg || res.data.msg)
    }
  } else {
    return Promise.reject(res)
  }
})

const clearUserInfo = () => {
  store.commit('user/setUserInfo', {})
  store.commit('user/setCode', '')
  store.commit('user/setUid', '')
  store.commit('user/setAccessToken', '')
}

export default service
